GuardedLinkedList

Struct GuardedLinkedList 

pub(crate) struct GuardedLinkedList<L: Link> {
    guard: NonNull<L::Target>,
}
An intrusive linked list, but instead of keeping pointers to the head and tail nodes, it uses a special guard node linked with those nodes. It means that the list is circular and every pointer of a node from the list is not None, including pointers from the guard node.

If a list is empty, then both pointers of the guard node are pointing at the guard node itself.

Fields

guard: NonNull<L::Target>

Pointer to the guard node.

Implementations

Source

impl<L: Link> GuardedLinkedList<L>

fn tail(&self) -> Option<NonNull<L::Target>>

pub(crate) fn pop_back(&mut self) -> Option<L::Handle>

Removes the last element from a list and returns it, or None if it is empty.